"""
Python module generated from Java source file org.bukkit.scoreboard.Score

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit import OfflinePlayer
from org.bukkit.scoreboard import *
from typing import Any, Callable, Iterable, Tuple


class Score:
    """
    A score entry for an .getEntry() entry on an .getObjective() objective. Changing this will not affect any other
    objective or scoreboard.
    """

    def getPlayer(self) -> "OfflinePlayer":
        """
        Gets the OfflinePlayer being tracked by this Score

        Returns
        - this Score's tracked player

        See
        - .getEntry()

        Deprecated
        - Scoreboards can contain entries that aren't players
        """
        ...


    def getEntry(self) -> str:
        """
        Gets the entry being tracked by this Score

        Returns
        - this Score's tracked entry
        """
        ...


    def getObjective(self) -> "Objective":
        """
        Gets the Objective being tracked by this Score

        Returns
        - this Score's tracked objective
        """
        ...


    def getScore(self) -> int:
        """
        Gets the current score

        Returns
        - the current score

        Raises
        - IllegalStateException: if the associated objective has been
            unregistered
        """
        ...


    def setScore(self, score: int) -> None:
        """
        Sets the current score.

        Arguments
        - score: New score

        Raises
        - IllegalStateException: if the associated objective has been
            unregistered
        """
        ...


    def isScoreSet(self) -> bool:
        """
        Shows if this score has been set at any point in time.

        Returns
        - if this score has been set before

        Raises
        - IllegalStateException: if the associated objective has been
            unregistered
        """
        ...


    def getScoreboard(self) -> "Scoreboard":
        """
        Gets the scoreboard for the associated objective.

        Returns
        - the owning objective's scoreboard, or null if it has been
            Objective.unregister() unregistered
        """
        ...



"""
Python module generated from Java source file java.util.Objects

Java source file obtained from artifact jdk version jdk

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.util import *
from java.util.function import Supplier
from jdk.internal.util import Preconditions
from jdk.internal.vm.annotation import ForceInline
from typing import Any, Callable, Iterable, Tuple


class Objects:
    """
    This class consists of `static` utility methods for operating
    on objects, or checking certain conditions before operation.  These utilities
    include `null`-safe or `null`-tolerant methods for computing the
    hash code of an object, returning a string for an object, comparing two
    objects, and checking if indexes or sub-range values are out of bounds.

    Since
    - 1.7
    """

    @staticmethod
    def equals(a: "Object", b: "Object") -> bool:
        """
        Returns `True` if the arguments are equal to each other
        and `False` otherwise.
        Consequently, if both arguments are `null`, `True`
        is returned.  Otherwise, if the first argument is not `null`, equality is determined by calling the Object.equals equals method of the first argument with the
        second argument of this method. Otherwise, `False` is
        returned.

        Arguments
        - a: an object
        - b: an object to be compared with `a` for equality

        Returns
        - `True` if the arguments are equal to each other
        and `False` otherwise

        See
        - Object.equals(Object)
        """
        ...


    @staticmethod
    def deepEquals(a: "Object", b: "Object") -> bool:
        """
        Returns `True` if the arguments are deeply equal to each other
        and `False` otherwise.
        
        Two `null` values are deeply equal.  If both arguments are
        arrays, the algorithm in Arrays.deepEquals(Object[],
        Object[]) Arrays.deepEquals is used to determine equality.
        Otherwise, equality is determined by using the Object.equals equals method of the first argument.

        Arguments
        - a: an object
        - b: an object to be compared with `a` for deep equality

        Returns
        - `True` if the arguments are deeply equal to each other
        and `False` otherwise

        See
        - Objects.equals(Object, Object)
        """
        ...


    @staticmethod
    def hashCode(o: "Object") -> int:
        """
        Returns the hash code of a non-`null` argument and 0 for
        a `null` argument.

        Arguments
        - o: an object

        Returns
        - the hash code of a non-`null` argument and 0 for
        a `null` argument

        See
        - Object.hashCode
        """
        ...


    @staticmethod
    def hash(*values: Tuple["Object", ...]) -> int:
        """
        Generates a hash code for a sequence of input values. The hash
        code is generated as if all the input values were placed into an
        array, and that array were hashed by calling Arrays.hashCode(Object[]).
        
        This method is useful for implementing Object.hashCode() on objects containing multiple fields. For
        example, if an object that has three fields, `x`, `y`, and `z`, one could write:
        
        <blockquote>```
        &#064;Override public int hashCode() {
            return Objects.hash(x, y, z);
        }
        ```</blockquote>
        
        **Warning: When a single object reference is supplied, the returned
        value does not equal the hash code of that object reference.** This
        value can be computed by calling .hashCode(Object).

        Arguments
        - values: the values to be hashed

        Returns
        - a hash value of the sequence of input values

        See
        - List.hashCode
        """
        ...


    @staticmethod
    def toString(o: "Object") -> str:
        """
        Returns the result of calling `toString` for a non-`null` argument and `"null"` for a `null` argument.

        Arguments
        - o: an object

        Returns
        - the result of calling `toString` for a non-`null` argument and `"null"` for a `null` argument

        See
        - String.valueOf(Object)
        """
        ...


    @staticmethod
    def toString(o: "Object", nullDefault: str) -> str:
        """
        Returns the result of calling `toString` on the first
        argument if the first argument is not `null` and returns
        the second argument otherwise.

        Arguments
        - o: an object
        - nullDefault: string to return if the first argument is
               `null`

        Returns
        - the result of calling `toString` on the first
        argument if it is not `null` and the second argument
        otherwise.

        See
        - Objects.toString(Object)
        """
        ...


    @staticmethod
    def compare(a: "T", b: "T", c: "Comparator"["T"]) -> int:
        """
        Returns 0 if the arguments are identical and `c.compare(a, b)` otherwise.
        Consequently, if both arguments are `null` 0
        is returned.
        
        Note that if one of the arguments is `null`, a `NullPointerException` may or may not be thrown depending on
        what ordering policy, if any, the Comparator Comparator
        chooses to have for `null` values.
        
        Type `<T>`: the type of the objects being compared

        Arguments
        - a: an object
        - b: an object to be compared with `a`
        - c: the `Comparator` to compare the first two arguments

        Returns
        - 0 if the arguments are identical and `c.compare(a, b)` otherwise.

        See
        - Comparator
        """
        ...


    @staticmethod
    def requireNonNull(obj: "T") -> "T":
        """
        Checks that the specified object reference is not `null`. This
        method is designed primarily for doing parameter validation in methods
        and constructors, as demonstrated below:
        <blockquote>```
        public Foo(Bar bar) {
            this.bar = Objects.requireNonNull(bar);
        }
        ```</blockquote>
        
        Type `<T>`: the type of the reference

        Arguments
        - obj: the object reference to check for nullity

        Returns
        - `obj` if not `null`

        Raises
        - NullPointerException: if `obj` is `null`
        """
        ...


    @staticmethod
    def requireNonNull(obj: "T", message: str) -> "T":
        """
        Checks that the specified object reference is not `null` and
        throws a customized NullPointerException if it is. This method
        is designed primarily for doing parameter validation in methods and
        constructors with multiple parameters, as demonstrated below:
        <blockquote>```
        public Foo(Bar bar, Baz baz) {
            this.bar = Objects.requireNonNull(bar, "bar must not be null");
            this.baz = Objects.requireNonNull(baz, "baz must not be null");
        }
        ```</blockquote>
        
        Type `<T>`: the type of the reference

        Arguments
        - obj: the object reference to check for nullity
        - message: detail message to be used in the event that a `NullPointerException` is thrown

        Returns
        - `obj` if not `null`

        Raises
        - NullPointerException: if `obj` is `null`
        """
        ...


    @staticmethod
    def isNull(obj: "Object") -> bool:
        """
        Returns `True` if the provided reference is `null` otherwise
        returns `False`.

        Arguments
        - obj: a reference to be checked against `null`

        Returns
        - `True` if the provided reference is `null` otherwise
        `False`

        See
        - java.util.function.Predicate

        Since
        - 1.8

        Unknown Tags
        - This method exists to be used as a
        java.util.function.Predicate, `filter(Objects::isNull)`
        """
        ...


    @staticmethod
    def nonNull(obj: "Object") -> bool:
        """
        Returns `True` if the provided reference is non-`null`
        otherwise returns `False`.

        Arguments
        - obj: a reference to be checked against `null`

        Returns
        - `True` if the provided reference is non-`null`
        otherwise `False`

        See
        - java.util.function.Predicate

        Since
        - 1.8

        Unknown Tags
        - This method exists to be used as a
        java.util.function.Predicate, `filter(Objects::nonNull)`
        """
        ...


    @staticmethod
    def requireNonNullElse(obj: "T", defaultObj: "T") -> "T":
        """
        Returns the first argument if it is non-`null` and
        otherwise returns the non-`null` second argument.
        
        Type `<T>`: the type of the reference

        Arguments
        - obj: an object
        - defaultObj: a non-`null` object to return if the first argument
                          is `null`

        Returns
        - the first argument if it is non-`null` and
               otherwise the second argument if it is non-`null`

        Raises
        - NullPointerException: if both `obj` is null and
               `defaultObj` is `null`

        Since
        - 9
        """
        ...


    @staticmethod
    def requireNonNullElseGet(obj: "T", supplier: "Supplier"["T"]) -> "T":
        """
        Returns the first argument if it is non-`null` and otherwise
        returns the non-`null` value of `supplier.get()`.
        
        Type `<T>`: the type of the first argument and return type

        Arguments
        - obj: an object
        - supplier: of a non-`null` object to return if the first argument
                        is `null`

        Returns
        - the first argument if it is non-`null` and otherwise
                the value from `supplier.get()` if it is non-`null`

        Raises
        - NullPointerException: if both `obj` is null and
               either the `supplier` is `null` or
               the `supplier.get()` value is `null`

        Since
        - 9
        """
        ...


    @staticmethod
    def requireNonNull(obj: "T", messageSupplier: "Supplier"[str]) -> "T":
        """
        Checks that the specified object reference is not `null` and
        throws a customized NullPointerException if it is.
        
        Unlike the method .requireNonNull(Object, String),
        this method allows creation of the message to be deferred until
        after the null check is made. While this may confer a
        performance advantage in the non-null case, when deciding to
        call this method care should be taken that the costs of
        creating the message supplier are less than the cost of just
        creating the string message directly.
        
        Type `<T>`: the type of the reference

        Arguments
        - obj: the object reference to check for nullity
        - messageSupplier: supplier of the detail message to be
        used in the event that a `NullPointerException` is thrown

        Returns
        - `obj` if not `null`

        Raises
        - NullPointerException: if `obj` is `null`

        Since
        - 1.8
        """
        ...


    @staticmethod
    def checkIndex(index: int, length: int) -> int:
        """
        Checks if the `index` is within the bounds of the range from
        `0` (inclusive) to `length` (exclusive).
        
        The `index` is defined to be out of bounds if any of the
        following inequalities is True:
        
         - `index < 0`
         - `index >= length`
         - `length < 0`, which is implied from the former inequalities

        Arguments
        - index: the index
        - length: the upper-bound (exclusive) of the range

        Returns
        - `index` if it is within bounds of the range

        Raises
        - IndexOutOfBoundsException: if the `index` is out of bounds

        Since
        - 9
        """
        ...


    @staticmethod
    def checkFromToIndex(fromIndex: int, toIndex: int, length: int) -> int:
        """
        Checks if the sub-range from `fromIndex` (inclusive) to
        `toIndex` (exclusive) is within the bounds of range from `0`
        (inclusive) to `length` (exclusive).
        
        The sub-range is defined to be out of bounds if any of the following
        inequalities is True:
        
         - `fromIndex < 0`
         - `fromIndex > toIndex`
         - `toIndex > length`
         - `length < 0`, which is implied from the former inequalities

        Arguments
        - fromIndex: the lower-bound (inclusive) of the sub-range
        - toIndex: the upper-bound (exclusive) of the sub-range
        - length: the upper-bound (exclusive) the range

        Returns
        - `fromIndex` if the sub-range within bounds of the range

        Raises
        - IndexOutOfBoundsException: if the sub-range is out of bounds

        Since
        - 9
        """
        ...


    @staticmethod
    def checkFromIndexSize(fromIndex: int, size: int, length: int) -> int:
        """
        Checks if the sub-range from `fromIndex` (inclusive) to
        `fromIndex + size` (exclusive) is within the bounds of range from
        `0` (inclusive) to `length` (exclusive).
        
        The sub-range is defined to be out of bounds if any of the following
        inequalities is True:
        
         - `fromIndex < 0`
         - `size < 0`
         - `fromIndex + size > length`, taking into account integer overflow
         - `length < 0`, which is implied from the former inequalities

        Arguments
        - fromIndex: the lower-bound (inclusive) of the sub-interval
        - size: the size of the sub-range
        - length: the upper-bound (exclusive) of the range

        Returns
        - `fromIndex` if the sub-range within bounds of the range

        Raises
        - IndexOutOfBoundsException: if the sub-range is out of bounds

        Since
        - 9
        """
        ...


    @staticmethod
    def checkIndex(index: int, length: int) -> int:
        """
        Checks if the `index` is within the bounds of the range from
        `0` (inclusive) to `length` (exclusive).
        
        The `index` is defined to be out of bounds if any of the
        following inequalities is True:
        
         - `index < 0`
         - `index >= length`
         - `length < 0`, which is implied from the former inequalities

        Arguments
        - index: the index
        - length: the upper-bound (exclusive) of the range

        Returns
        - `index` if it is within bounds of the range

        Raises
        - IndexOutOfBoundsException: if the `index` is out of bounds

        Since
        - 16
        """
        ...


    @staticmethod
    def checkFromToIndex(fromIndex: int, toIndex: int, length: int) -> int:
        """
        Checks if the sub-range from `fromIndex` (inclusive) to
        `toIndex` (exclusive) is within the bounds of range from `0`
        (inclusive) to `length` (exclusive).
        
        The sub-range is defined to be out of bounds if any of the following
        inequalities is True:
        
         - `fromIndex < 0`
         - `fromIndex > toIndex`
         - `toIndex > length`
         - `length < 0`, which is implied from the former inequalities

        Arguments
        - fromIndex: the lower-bound (inclusive) of the sub-range
        - toIndex: the upper-bound (exclusive) of the sub-range
        - length: the upper-bound (exclusive) the range

        Returns
        - `fromIndex` if the sub-range within bounds of the range

        Raises
        - IndexOutOfBoundsException: if the sub-range is out of bounds

        Since
        - 16
        """
        ...


    @staticmethod
    def checkFromIndexSize(fromIndex: int, size: int, length: int) -> int:
        """
        Checks if the sub-range from `fromIndex` (inclusive) to
        `fromIndex + size` (exclusive) is within the bounds of range from
        `0` (inclusive) to `length` (exclusive).
        
        The sub-range is defined to be out of bounds if any of the following
        inequalities is True:
        
         - `fromIndex < 0`
         - `size < 0`
         - `fromIndex + size > length`, taking into account integer overflow
         - `length < 0`, which is implied from the former inequalities

        Arguments
        - fromIndex: the lower-bound (inclusive) of the sub-interval
        - size: the size of the sub-range
        - length: the upper-bound (exclusive) of the range

        Returns
        - `fromIndex` if the sub-range within bounds of the range

        Raises
        - IndexOutOfBoundsException: if the sub-range is out of bounds

        Since
        - 16
        """
        ...



"""
Python module generated from Java source file org.bukkit.event.entity.FoodLevelChangeEvent

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.entity import HumanEntity
from org.bukkit.event import Cancellable
from org.bukkit.event import HandlerList
from org.bukkit.event.entity import *
from org.bukkit.inventory import ItemStack
from typing import Any, Callable, Iterable, Tuple


class FoodLevelChangeEvent(EntityEvent, Cancellable):
    """
    Called when a human entity's food level changes
    """

    def __init__(self, what: "HumanEntity", level: int):
        ...


    def __init__(self, what: "HumanEntity", level: int, item: "ItemStack"):
        ...


    def getEntity(self) -> "HumanEntity":
        ...


    def getItem(self) -> "ItemStack":
        """
        Gets the item that triggered this event, if any.

        Returns
        - an ItemStack for the item being consumed
        """
        ...


    def getFoodLevel(self) -> int:
        """
        Gets the resultant food level that the entity involved in this event
        should be set to.
        
        Where 20 is a full food bar and 0 is an empty one.

        Returns
        - The resultant food level
        """
        ...


    def setFoodLevel(self, level: int) -> None:
        """
        Sets the resultant food level that the entity involved in this event
        should be set to

        Arguments
        - level: the resultant food level that the entity involved in this
            event should be set to
        """
        ...


    def isCancelled(self) -> bool:
        ...


    def setCancelled(self, cancel: bool) -> None:
        ...


    def getHandlers(self) -> "HandlerList":
        ...


    @staticmethod
    def getHandlerList() -> "HandlerList":
        ...



"""
Python module generated from Java source file org.bukkit.event.player.PlayerInteractEvent

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit import Material
from org.bukkit.block import Block
from org.bukkit.block import BlockFace
from org.bukkit.entity import Player
from org.bukkit.event import Cancellable
from org.bukkit.event import HandlerList
from org.bukkit.event.block import Action
from org.bukkit.event.block import BlockCanBuildEvent
from org.bukkit.event.player import *
from org.bukkit.inventory import EquipmentSlot
from org.bukkit.inventory import ItemStack
from org.bukkit.util import Vector
from typing import Any, Callable, Iterable, Tuple


class PlayerInteractEvent(PlayerEvent, Cancellable):
    """
    Represents an event that is called when a player interacts with an object or
    air, potentially fired once for each hand. The hand can be determined using
    .getHand().
    
    This event will fire as cancelled if the vanilla behavior is to do nothing
    (e.g interacting with air). For the purpose of avoiding doubt, this means
    that the event will only be in the cancelled state if it is fired as a result
    of some prediction made by the server where no subsequent code will run,
    rather than when the subsequent interaction activity (e.g. placing a block in
    an illegal position (BlockCanBuildEvent) will fail.
    """

    def __init__(self, who: "Player", action: "Action", item: "ItemStack", clickedBlock: "Block", clickedFace: "BlockFace"):
        ...


    def __init__(self, who: "Player", action: "Action", item: "ItemStack", clickedBlock: "Block", clickedFace: "BlockFace", hand: "EquipmentSlot"):
        ...


    def __init__(self, who: "Player", action: "Action", item: "ItemStack", clickedBlock: "Block", clickedFace: "BlockFace", hand: "EquipmentSlot", clickedPosition: "Vector"):
        ...


    def getAction(self) -> "Action":
        """
        Returns the action type

        Returns
        - Action returns the type of interaction
        """
        ...


    def isCancelled(self) -> bool:
        """
        Gets the cancellation state of this event. Set to True if you want to
        prevent buckets from placing water and so forth

        Returns
        - boolean cancellation state

        Deprecated
        - This event has two possible cancellation states, one for
        .useInteractedBlock() and one for .useItemInHand(). It is
        possible a call might have the former False, but the latter True, eg in
        the case of using a firework whilst gliding. Callers should check the
        relevant methods individually.
        """
        ...


    def setCancelled(self, cancel: bool) -> None:
        """
        Sets the cancellation state of this event. A canceled event will not be
        executed in the server, but will still pass to other plugins
        
        Canceling this event will prevent use of food (player won't lose the
        food item), prevent bows/snowballs/eggs from firing, etc. (player won't
        lose the ammo)

        Arguments
        - cancel: True if you wish to cancel this event
        """
        ...


    def getItem(self) -> "ItemStack":
        """
        Returns the item in hand represented by this event

        Returns
        - ItemStack the item used
        """
        ...


    def getMaterial(self) -> "Material":
        """
        Convenience method. Returns the material of the item represented by
        this event

        Returns
        - Material the material of the item used
        """
        ...


    def hasBlock(self) -> bool:
        """
        Check if this event involved a block

        Returns
        - boolean True if it did
        """
        ...


    def hasItem(self) -> bool:
        """
        Check if this event involved an item

        Returns
        - boolean True if it did
        """
        ...


    def isBlockInHand(self) -> bool:
        """
        Convenience method to inform the user whether this was a block
        placement event.

        Returns
        - boolean True if the item in hand was a block
        """
        ...


    def getClickedBlock(self) -> "Block":
        """
        Returns the clicked block

        Returns
        - Block returns the block clicked with this item.
        """
        ...


    def getBlockFace(self) -> "BlockFace":
        """
        Returns the face of the block that was clicked

        Returns
        - BlockFace returns the face of the block that was clicked
        """
        ...


    def useInteractedBlock(self) -> "Result":
        """
        This controls the action to take with the block (if any) that was
        clicked on. This event gets processed for all blocks, but most don't
        have a default action

        Returns
        - the action to take with the interacted block
        """
        ...


    def setUseInteractedBlock(self, useInteractedBlock: "Result") -> None:
        """
        Arguments
        - useInteractedBlock: the action to take with the interacted block
        """
        ...


    def useItemInHand(self) -> "Result":
        """
        This controls the action to take with the item the player is holding.
        This includes both blocks and items (such as flint and steel or
        records). When this is set to default, it will be allowed if no action
        is taken on the interacted block.

        Returns
        - the action to take with the item in hand
        """
        ...


    def setUseItemInHand(self, useItemInHand: "Result") -> None:
        """
        Arguments
        - useItemInHand: the action to take with the item in hand
        """
        ...


    def getHand(self) -> "EquipmentSlot":
        """
        The hand used to perform this interaction. May be null in the case of
        Action.PHYSICAL.

        Returns
        - the hand used to interact. May be null.
        """
        ...


    def getClickedPosition(self) -> "Vector":
        """
        Gets the exact position on the block the player interacted with, this will
        be null outside of Action.RIGHT_CLICK_BLOCK.
        
        All vector components are between 0.0 and 1.0 inclusive.

        Returns
        - the clicked position. May be null.
        """
        ...


    def getHandlers(self) -> "HandlerList":
        ...


    @staticmethod
    def getHandlerList() -> "HandlerList":
        ...



from .Types import Types
from .TypeVisitor import TypeVisitor
from .TypeToken import TypeToken
from .TypeToInstanceMap import TypeToInstanceMap
from .TypeResolver import TypeResolver
from .TypeParameter import TypeParameter
from .TypeCapture import TypeCapture
from .Reflection import Reflection
from .ParametricNullness import ParametricNullness
from .Parameter import Parameter
from .MutableTypeToInstanceMap import MutableTypeToInstanceMap
from .Invokable import Invokable
from .ImmutableTypeToInstanceMap import ImmutableTypeToInstanceMap
from .IgnoreJRERequirement import IgnoreJRERequirement
from .ElementTypesAreNonnullByDefault import ElementTypesAreNonnullByDefault
from .ClassPath import ClassPath
from .AbstractInvocationHandler import AbstractInvocationHandler


"""
Python module generated from Java source file org.bukkit.event.player.PlayerSignOpenEvent

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from enum import Enum
from org.bukkit.block import Sign
from org.bukkit.block.sign import Side
from org.bukkit.entity import Player
from org.bukkit.event import Cancellable
from org.bukkit.event import HandlerList
from org.bukkit.event.player import *
from typing import Any, Callable, Iterable, Tuple


class PlayerSignOpenEvent(PlayerEvent, Cancellable):
    """
    This event is fired when a sign is opened by the player.
    """

    def __init__(self, player: "Player", sign: "Sign", side: "Side", cause: "Cause"):
        ...


    def getSign(self) -> "Sign":
        """
        Gets the sign that was opened.

        Returns
        - opened sign
        """
        ...


    def getSide(self) -> "Side":
        """
        Gets side of the sign opened.

        Returns
        - side of sign opened
        """
        ...


    def getCause(self) -> "Cause":
        """
        Gets the cause of the sign open.

        Returns
        - sign open cause
        """
        ...


    def isCancelled(self) -> bool:
        ...


    def setCancelled(self, cancel: bool) -> None:
        ...


    def getHandlers(self) -> "HandlerList":
        ...


    @staticmethod
    def getHandlerList() -> "HandlerList":
        ...


    class Cause(Enum):

        INTERACT = 0
        """
        Indicate the sign was opened because of an interaction.
        """
        PLACE = 1
        """
        Indicate the sign was opened because the sign was placed.
        """
        PLUGIN = 2
        """
        Indicate the sign was opened because of a plugin.
        """
        UNKNOWN = 3
        """
        Indicate the sign was opened for an unknown reason.
        """



"""
Python module generated from Java source file com.google.common.collect.ImmutableRangeSet

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtIncompatible
from com.google.common.annotations import J2ktIncompatible
from com.google.common.collect import *
from com.google.common.collect.SortedLists import KeyAbsentBehavior
from com.google.common.collect.SortedLists import KeyPresentBehavior
from com.google.common.primitives import Ints
from com.google.errorprone.annotations import CanIgnoreReturnValue
from com.google.errorprone.annotations import DoNotCall
from com.google.errorprone.annotations.concurrent import LazyInit
from java.io import InvalidObjectException
from java.io import ObjectInputStream
from java.io import Serializable
from java.util import Collections
from java.util import Iterator
from java.util import NoSuchElementException
from java.util.stream import Collector
from javax.annotation import CheckForNull
from typing import Any, Callable, Iterable, Tuple


class ImmutableRangeSet(AbstractRangeSet, Serializable):
    """
    A RangeSet whose contents will never change, with many other important properties
    detailed at ImmutableCollection.

    Author(s)
    - Louis Wasserman

    Since
    - 14.0
    """

    @staticmethod
    def toImmutableRangeSet() -> "Collector"["Range"["E"], Any, "ImmutableRangeSet"["E"]]:
        """
        Returns a `Collector` that accumulates the input elements into a new `ImmutableRangeSet`. As in Builder, overlapping ranges are not permitted and adjacent
        ranges will be merged.

        Since
        - 23.1
        """
        ...


    @staticmethod
    def of() -> "ImmutableRangeSet"["C"]:
        """
        Returns an empty immutable range set.
        
        **Performance note:** the instance returned is a singleton.
        """
        ...


    @staticmethod
    def of(range: "Range"["C"]) -> "ImmutableRangeSet"["C"]:
        """
        Returns an immutable range set containing the specified single range. If Range.isEmpty()
        range.isEmpty(), this is equivalent to ImmutableRangeSet.of().
        """
        ...


    @staticmethod
    def copyOf(rangeSet: "RangeSet"["C"]) -> "ImmutableRangeSet"["C"]:
        """
        Returns an immutable copy of the specified `RangeSet`.
        """
        ...


    @staticmethod
    def copyOf(ranges: Iterable["Range"["C"]]) -> "ImmutableRangeSet"["C"]:
        """
        Returns an `ImmutableRangeSet` containing each of the specified disjoint ranges.
        Overlapping ranges and empty ranges are forbidden, though adjacent ranges are permitted and
        will be merged.

        Raises
        - IllegalArgumentException: if any ranges overlap or are empty

        Since
        - 21.0
        """
        ...


    @staticmethod
    def unionOf(ranges: Iterable["Range"["C"]]) -> "ImmutableRangeSet"["C"]:
        """
        Returns an `ImmutableRangeSet` representing the union of the specified ranges.
        
        This is the smallest `RangeSet` which encloses each of the specified ranges. Duplicate
        or connected ranges are permitted, and will be coalesced in the result.

        Since
        - 21.0
        """
        ...


    def intersects(self, otherRange: "Range"["C"]) -> bool:
        ...


    def encloses(self, otherRange: "Range"["C"]) -> bool:
        ...


    def rangeContaining(self, value: "C") -> "Range"["C"]:
        ...


    def span(self) -> "Range"["C"]:
        ...


    def isEmpty(self) -> bool:
        ...


    def add(self, range: "Range"["C"]) -> None:
        """
        Guaranteed to throw an exception and leave the `RangeSet` unmodified.

        Raises
        - UnsupportedOperationException: always

        Deprecated
        - Unsupported operation.
        """
        ...


    def addAll(self, other: "RangeSet"["C"]) -> None:
        """
        Guaranteed to throw an exception and leave the `RangeSet` unmodified.

        Raises
        - UnsupportedOperationException: always

        Deprecated
        - Unsupported operation.
        """
        ...


    def addAll(self, other: Iterable["Range"["C"]]) -> None:
        """
        Guaranteed to throw an exception and leave the `RangeSet` unmodified.

        Raises
        - UnsupportedOperationException: always

        Deprecated
        - Unsupported operation.
        """
        ...


    def remove(self, range: "Range"["C"]) -> None:
        """
        Guaranteed to throw an exception and leave the `RangeSet` unmodified.

        Raises
        - UnsupportedOperationException: always

        Deprecated
        - Unsupported operation.
        """
        ...


    def removeAll(self, other: "RangeSet"["C"]) -> None:
        """
        Guaranteed to throw an exception and leave the `RangeSet` unmodified.

        Raises
        - UnsupportedOperationException: always

        Deprecated
        - Unsupported operation.
        """
        ...


    def removeAll(self, other: Iterable["Range"["C"]]) -> None:
        """
        Guaranteed to throw an exception and leave the `RangeSet` unmodified.

        Raises
        - UnsupportedOperationException: always

        Deprecated
        - Unsupported operation.
        """
        ...


    def asRanges(self) -> "ImmutableSet"["Range"["C"]]:
        ...


    def asDescendingSetOfRanges(self) -> "ImmutableSet"["Range"["C"]]:
        ...


    def complement(self) -> "ImmutableRangeSet"["C"]:
        ...


    def union(self, other: "RangeSet"["C"]) -> "ImmutableRangeSet"["C"]:
        """
        Returns a new range set consisting of the union of this range set and `other`.
        
        This is essentially the same as `TreeRangeSet.create(this).addAll(other)` except it
        returns an `ImmutableRangeSet`.

        Since
        - 21.0
        """
        ...


    def intersection(self, other: "RangeSet"["C"]) -> "ImmutableRangeSet"["C"]:
        """
        Returns a new range set consisting of the intersection of this range set and `other`.
        
        This is essentially the same as `TreeRangeSet.create(this).removeAll(other.complement())` except it returns an `ImmutableRangeSet`.

        Since
        - 21.0
        """
        ...


    def difference(self, other: "RangeSet"["C"]) -> "ImmutableRangeSet"["C"]:
        """
        Returns a new range set consisting of the difference of this range set and `other`.
        
        This is essentially the same as `TreeRangeSet.create(this).removeAll(other)` except it
        returns an `ImmutableRangeSet`.

        Since
        - 21.0
        """
        ...


    def subRangeSet(self, range: "Range"["C"]) -> "ImmutableRangeSet"["C"]:
        """
        Returns a view of the intersection of this range set with the given range.
        """
        ...


    def asSet(self, domain: "DiscreteDomain"["C"]) -> "ImmutableSortedSet"["C"]:
        """
        Returns an ImmutableSortedSet containing the same values in the given domain
        RangeSet.contains contained by this range set.
        
        **Note:** `a.asSet(d).equals(b.asSet(d))` does not imply `a.equals(b)`! For
        example, `a` and `b` could be `[2..4]` and `(1..5)`, or the empty
        ranges `[3..3)` and `[4..4)`.
        
        **Warning:** Be extremely careful what you do with the `asSet` view of a large
        range set (such as `ImmutableRangeSet.of(Range.greaterThan(0))`). Certain operations on
        such a set can be performed efficiently, but others (such as Set.hashCode or Collections.frequency) can cause major performance problems.
        
        The returned set's Object.toString method returns a shorthand form of the set's
        contents, such as `"[1..100]`"}.

        Raises
        - IllegalArgumentException: if neither this range nor the domain has a lower bound, or if
            neither has an upper bound
        """
        ...


    @staticmethod
    def builder() -> "Builder"["C"]:
        """
        Returns a new builder for an immutable range set.
        """
        ...


    class Builder:
        """
        A builder for immutable range sets.

        Since
        - 14.0
        """

        def __init__(self):
            ...


        def add(self, range: "Range"["C"]) -> "Builder"["C"]:
            """
            Add the specified range to this builder. Adjacent ranges are permitted and will be merged,
            but overlapping ranges will cause an exception when .build() is called.

            Raises
            - IllegalArgumentException: if `range` is empty
            """
            ...


        def addAll(self, ranges: "RangeSet"["C"]) -> "Builder"["C"]:
            """
            Add all ranges from the specified range set to this builder. Adjacent ranges are permitted
            and will be merged, but overlapping ranges will cause an exception when .build() is
            called.
            """
            ...


        def addAll(self, ranges: Iterable["Range"["C"]]) -> "Builder"["C"]:
            """
            Add all of the specified ranges to this builder. Adjacent ranges are permitted and will be
            merged, but overlapping ranges will cause an exception when .build() is called.

            Raises
            - IllegalArgumentException: if any inserted ranges are empty

            Since
            - 21.0
            """
            ...


        def build(self) -> "ImmutableRangeSet"["C"]:
            """
            Returns an `ImmutableRangeSet` containing the ranges added to this builder.

            Raises
            - IllegalArgumentException: if any input ranges have nonempty overlap
            """
            ...



"""
Python module generated from Java source file org.bukkit.event.player.PlayerToggleSprintEvent

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.entity import Player
from org.bukkit.event import Cancellable
from org.bukkit.event import HandlerList
from org.bukkit.event.player import *
from typing import Any, Callable, Iterable, Tuple


class PlayerToggleSprintEvent(PlayerEvent, Cancellable):
    """
    Called when a player toggles their sprinting state
    """

    def __init__(self, player: "Player", isSprinting: bool):
        ...


    def isSprinting(self) -> bool:
        """
        Gets whether the player is now sprinting or not.

        Returns
        - sprinting state
        """
        ...


    def isCancelled(self) -> bool:
        ...


    def setCancelled(self, cancel: bool) -> None:
        ...


    def getHandlers(self) -> "HandlerList":
        ...


    @staticmethod
    def getHandlerList() -> "HandlerList":
        ...



"""
Python module generated from Java source file com.google.common.collect.ImmutableMultisetGwtSerializationDependencies

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtCompatible
from com.google.common.collect import *
from typing import Any, Callable, Iterable, Tuple


class ImmutableMultisetGwtSerializationDependencies(ImmutableCollection):
    """
    A dummy superclass to support GWT serialization of the element type of an ImmutableMultiset. The GWT supersource for this class contains a field of type `E`.
    
    For details about this hack, see `GwtSerializationDependencies`, which takes the same
    approach but with a subclass rather than a superclass.
    
    TODO(cpovirk): Consider applying this subclass approach to our other types.
    
    For `ImmutableMultiset` in particular, I ran into a problem with the `GwtSerializationDependencies` approach: When autogenerating a serializer for the new class, GWT
    tries to refer to our dummy serializer for the superclass,
    ImmutableMultiset_CustomFieldSerializer. But that type has no methods (since it's never actually
    used). We could probably fix the problem by adding dummy methods to that class, but that is
    starting to sound harder than taking the superclass approach, which I've been coming to like,
    anyway, since it doesn't require us to declare dummy methods (though occasionally constructors)
    and make types non-final.
    """





"""
Python module generated from Java source file org.bukkit.entity.minecart.RideableMinecart

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.entity import Minecart
from org.bukkit.entity.minecart import *
from typing import Any, Callable, Iterable, Tuple


class RideableMinecart(Minecart):
    """
    Represents a minecart that can have certain org.bukkit.entity.Entity entities as passengers. Normal passengers
    include all org.bukkit.entity.LivingEntity living entities with
    the exception of org.bukkit.entity.IronGolem iron golems.
    Non-player entities that meet normal passenger criteria automatically
    mount these minecarts when close enough.
    """





"""
Python module generated from Java source file com.google.common.util.concurrent.JdkFutureAdapters

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtIncompatible
from com.google.common.annotations import J2ktIncompatible
from com.google.common.util.concurrent import *
from java.util.concurrent import Executor
from java.util.concurrent import Executors
from java.util.concurrent import Future
from java.util.concurrent import ThreadFactory
from java.util.concurrent.atomic import AtomicBoolean
from org.checkerframework.checker.nullness.qual import Nullable
from typing import Any, Callable, Iterable, Tuple


class JdkFutureAdapters:
    """
    Utilities necessary for working with libraries that supply plain Future instances. Note
    that, whenever possible, it is strongly preferred to modify those libraries to return `ListenableFuture` directly.
    
    For interoperability between `ListenableFuture` and **`CompletableFuture`**,
    consider <a href="https://github.com/lukas-krecan/future-converter">Future Converter</a>.

    Author(s)
    - Sven Mawson

    Since
    - 10.0 (replacing `Futures.makeListenable`, which existed in 1.0)
    """

    @staticmethod
    def listenInPoolThread(future: "Future"["V"]) -> "ListenableFuture"["V"]:
        """
        Assigns a thread to the given Future to provide ListenableFuture functionality.
        
        **Warning:** If the input future does not already implement `ListenableFuture`, the
        returned future will emulate ListenableFuture.addListener by taking a thread from an
        internal, unbounded pool at the first call to `addListener` and holding it until the
        future is Future.isDone() done.
        
        Prefer to create `ListenableFuture` instances with SettableFuture, MoreExecutors.listeningDecorator( java.util.concurrent.ExecutorService), ListenableFutureTask, AbstractFuture, and other utilities over creating plain `Future` instances to be upgraded to `ListenableFuture` after the fact.
        """
        ...


    @staticmethod
    def listenInPoolThread(future: "Future"["V"], executor: "Executor") -> "ListenableFuture"["V"]:
        """
        Submits a blocking task for the given Future to provide ListenableFuture
        functionality.
        
        **Warning:** If the input future does not already implement `ListenableFuture`, the
        returned future will emulate ListenableFuture.addListener by submitting a task to the
        given executor at the first call to `addListener`. The task must be started by the
        executor promptly, or else the returned `ListenableFuture` may fail to work. The task's
        execution consists of blocking until the input future is Future.isDone() done, so
        each call to this method may claim and hold a thread for an arbitrary length of time. Use of
        bounded executors or other executors that may fail to execute a task promptly may result in
        deadlocks.
        
        Prefer to create `ListenableFuture` instances with SettableFuture, MoreExecutors.listeningDecorator( java.util.concurrent.ExecutorService), ListenableFutureTask, AbstractFuture, and other utilities over creating plain `Future` instances to be upgraded to `ListenableFuture` after the fact.

        Since
        - 12.0
        """
        ...



"""
Python module generated from Java source file org.bukkit.block.data.type.TrialSpawner

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from enum import Enum
from org.bukkit.block.data import BlockData
from org.bukkit.block.data.type import *
from typing import Any, Callable, Iterable, Tuple


class TrialSpawner(BlockData):
    """
    'trial_spawner_state' indicates the current operational phase of the spawner.
    
    'ominous' indicates if the block has ominous effects.
    """

    def getTrialSpawnerState(self) -> "State":
        """
        Gets the value of the 'trial_spawner_state' property.

        Returns
        - the 'trial_spawner_state' value
        """
        ...


    def setTrialSpawnerState(self, state: "State") -> None:
        """
        Sets the value of the 'trial_spawner_state' property.

        Arguments
        - state: the new 'trial_spawner_state' value
        """
        ...


    def isOminous(self) -> bool:
        """
        Gets the value of the 'ominous' property.

        Returns
        - the 'ominous' value
        """
        ...


    def setOminous(self, ominous: bool) -> None:
        """
        Sets the value of the 'ominous' property.

        Arguments
        - ominous: the new 'ominous' value
        """
        ...


    class State(Enum):

        INACTIVE = 0
        WAITING_FOR_PLAYERS = 1
        ACTIVE = 2
        WAITING_FOR_REWARD_EJECTION = 3
        EJECTING_REWARD = 4
        COOLDOWN = 5



"""
Python module generated from Java source file org.bukkit.entity.Interaction

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit import OfflinePlayer
from org.bukkit.entity import *
from typing import Any, Callable, Iterable, Tuple


class Interaction(Entity):
    """
    Represents an entity designed to only record interactions.
    """

    def getInteractionWidth(self) -> float:
        """
        Gets the width of this interaction entity.

        Returns
        - width
        """
        ...


    def setInteractionWidth(self, width: float) -> None:
        """
        Sets the width of this interaction entity.

        Arguments
        - width: new width
        """
        ...


    def getInteractionHeight(self) -> float:
        """
        Gets the height of this interaction entity.

        Returns
        - height
        """
        ...


    def setInteractionHeight(self, height: float) -> None:
        """
        Sets the height of this interaction entity.

        Arguments
        - height: new height
        """
        ...


    def isResponsive(self) -> bool:
        """
        Gets if this interaction entity should trigger a response when interacted
        with.

        Returns
        - response setting
        """
        ...


    def setResponsive(self, response: bool) -> None:
        """
        Sets if this interaction entity should trigger a response when interacted
        with.

        Arguments
        - response: new setting
        """
        ...


    def getLastAttack(self) -> "PreviousInteraction":
        """
        Gets the last attack on this interaction entity.

        Returns
        - last attack data, if present
        """
        ...


    def getLastInteraction(self) -> "PreviousInteraction":
        """
        Gets the last interaction on this entity.

        Returns
        - last interaction data, if present
        """
        ...


    class PreviousInteraction:
        """
        Represents a previous interaction with this entity.
        """

        def getPlayer(self) -> "OfflinePlayer":
            """
            Get the previous interacting player.

            Returns
            - interacting player
            """
            ...


        def getTimestamp(self) -> int:
            """
            Gets the Unix timestamp at when this interaction occurred.

            Returns
            - interaction timestamp
            """
            ...



"""
Python module generated from Java source file org.bukkit.plugin.UnknownDependencyException

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.plugin import *
from typing import Any, Callable, Iterable, Tuple


class UnknownDependencyException(RuntimeException):
    """
    Thrown when attempting to load an invalid Plugin file
    """

    def __init__(self, throwable: "Throwable"):
        """
        Constructs a new UnknownDependencyException based on the given
        Exception

        Arguments
        - throwable: Exception that triggered this Exception
        """
        ...


    def __init__(self, message: str):
        """
        Constructs a new UnknownDependencyException with the given message

        Arguments
        - message: Brief message explaining the cause of the exception
        """
        ...


    def __init__(self, throwable: "Throwable", message: str):
        """
        Constructs a new UnknownDependencyException based on the given
        Exception

        Arguments
        - message: Brief message explaining the cause of the exception
        - throwable: Exception that triggered this Exception
        """
        ...


    def __init__(self):
        """
        Constructs a new UnknownDependencyException
        """
        ...



"""
Python module generated from Java source file com.google.common.collect.MapMakerInternalMap

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtIncompatible
from com.google.common.annotations import J2ktIncompatible
from com.google.common.annotations import VisibleForTesting
from com.google.common.base import Equivalence
from com.google.common.collect import *
from com.google.common.collect.MapMaker import Dummy
from com.google.common.primitives import Ints
from com.google.errorprone.annotations import CanIgnoreReturnValue
from com.google.errorprone.annotations.concurrent import GuardedBy
from com.google.errorprone.annotations.concurrent import LazyInit
from com.google.j2objc.annotations import Weak
from com.google.j2objc.annotations import WeakOuter
from java.io import IOException
from java.io import InvalidObjectException
from java.io import ObjectInputStream
from java.io import ObjectOutputStream
from java.io import Serializable
from java.lang.ref import Reference
from java.lang.ref import ReferenceQueue
from java.lang.ref import WeakReference
from java.util import AbstractCollection
from java.util import AbstractSet
from java.util import Iterator
from java.util import NoSuchElementException
from java.util.concurrent import CancellationException
from java.util.concurrent import ConcurrentMap
from java.util.concurrent.atomic import AtomicInteger
from java.util.concurrent.atomic import AtomicReferenceArray
from java.util.concurrent.locks import ReentrantLock
from javax.annotation import CheckForNull
from typing import Any, Callable, Iterable, Tuple


class MapMakerInternalMap(AbstractMap, ConcurrentMap, Serializable):

    def isEmpty(self) -> bool:
        ...


    def size(self) -> int:
        ...


    def get(self, key: "Object") -> "V":
        ...


    def containsKey(self, key: "Object") -> bool:
        ...


    def containsValue(self, value: "Object") -> bool:
        ...


    def put(self, key: "K", value: "V") -> "V":
        ...


    def putIfAbsent(self, key: "K", value: "V") -> "V":
        ...


    def putAll(self, m: dict["K", "V"]) -> None:
        ...


    def remove(self, key: "Object") -> "V":
        ...


    def remove(self, key: "Object", value: "Object") -> bool:
        ...


    def replace(self, key: "K", oldValue: "V", newValue: "V") -> bool:
        ...


    def replace(self, key: "K", value: "V") -> "V":
        ...


    def clear(self) -> None:
        ...


    def keySet(self) -> set["K"]:
        ...


    def values(self) -> Iterable["V"]:
        ...


    def entrySet(self) -> set["Entry"["K", "V"]]:
        ...



"""
Python module generated from Java source file org.joml.AxisAngle4d

Java source file obtained from artifact joml version 1.10.8

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.io import Externalizable
from java.io import IOException
from java.io import ObjectInput
from java.io import ObjectOutput
from java.text import DecimalFormat
from java.text import NumberFormat
from org.joml import *
from typing import Any, Callable, Iterable, Tuple


class AxisAngle4d(Externalizable, Cloneable):
    """
    Represents a 3D rotation of a given radians about an axis represented as an
    unit 3D vector.
    
    This class uses double-precision components.

    Author(s)
    - Kai Burjack
    """

    def __init__(self):
        """
        Create a new AxisAngle4d with zero rotation about `(0, 0, 1)`.
        """
        ...


    def __init__(self, a: "AxisAngle4d"):
        """
        Create a new AxisAngle4d with the same values of `a`.

        Arguments
        - a: the AngleAxis4d to copy the values from
        """
        ...


    def __init__(self, a: "AxisAngle4f"):
        """
        Create a new AxisAngle4d with the same values of `a`.

        Arguments
        - a: the AngleAxis4f to copy the values from
        """
        ...


    def __init__(self, q: "Quaternionfc"):
        """
        Create a new AxisAngle4d from the given Quaternionfc.
        
        Reference: <a href=
        "http://www.euclideanspace.com/maths/geometry/rotations/conversions/quaternionToAngle/"
        >http://www.euclideanspace.com</a>

        Arguments
        - q: the quaternion from which to create the new AngleAxis4f
        """
        ...


    def __init__(self, q: "Quaterniondc"):
        """
        Create a new AxisAngle4d from the given Quaterniondc.
        
        Reference: <a href=
        "http://www.euclideanspace.com/maths/geometry/rotations/conversions/quaternionToAngle/"
        >http://www.euclideanspace.com</a>

        Arguments
        - q: the quaternion from which to create the new AngleAxis4d
        """
        ...


    def __init__(self, angle: float, x: float, y: float, z: float):
        """
        Create a new AxisAngle4d with the given values.

        Arguments
        - angle: the angle in radians
        - x: the x-coordinate of the rotation axis
        - y: the y-coordinate of the rotation axis
        - z: the z-coordinate of the rotation axis
        """
        ...


    def __init__(self, angle: float, v: "Vector3dc"):
        """
        Create a new AxisAngle4d with the given values.

        Arguments
        - angle: the angle in radians
        - v: the rotation axis as a Vector3dc
        """
        ...


    def __init__(self, angle: float, v: "Vector3f"):
        """
        Create a new AxisAngle4d with the given values.

        Arguments
        - angle: the angle in radians
        - v: the rotation axis as a Vector3f
        """
        ...


    def set(self, a: "AxisAngle4d") -> "AxisAngle4d":
        """
        Set this AxisAngle4d to the values of `a`.

        Arguments
        - a: the AngleAxis4f to copy the values from

        Returns
        - this
        """
        ...


    def set(self, a: "AxisAngle4f") -> "AxisAngle4d":
        """
        Set this AxisAngle4d to the values of `a`.

        Arguments
        - a: the AngleAxis4f to copy the values from

        Returns
        - this
        """
        ...


    def set(self, angle: float, x: float, y: float, z: float) -> "AxisAngle4d":
        """
        Set this AxisAngle4d to the given values.

        Arguments
        - angle: the angle in radians
        - x: the x-coordinate of the rotation axis
        - y: the y-coordinate of the rotation axis
        - z: the z-coordinate of the rotation axis

        Returns
        - this
        """
        ...


    def set(self, angle: float, v: "Vector3dc") -> "AxisAngle4d":
        """
        Set this AxisAngle4d to the given values.

        Arguments
        - angle: the angle in radians
        - v: the rotation axis as a Vector3dc

        Returns
        - this
        """
        ...


    def set(self, angle: float, v: "Vector3f") -> "AxisAngle4d":
        """
        Set this AxisAngle4d to the given values.

        Arguments
        - angle: the angle in radians
        - v: the rotation axis as a Vector3f

        Returns
        - this
        """
        ...


    def set(self, q: "Quaternionfc") -> "AxisAngle4d":
        """
        Set this AxisAngle4d to be equivalent to the given
        Quaternionfc.

        Arguments
        - q: the quaternion to set this AngleAxis4d from

        Returns
        - this
        """
        ...


    def set(self, q: "Quaterniondc") -> "AxisAngle4d":
        """
        Set this AxisAngle4d to be equivalent to the given
        Quaterniondc.

        Arguments
        - q: the quaternion to set this AngleAxis4d from

        Returns
        - this
        """
        ...


    def set(self, m: "Matrix3fc") -> "AxisAngle4d":
        """
        Set this AxisAngle4d to be equivalent to the rotation 
        of the given Matrix3fc.
        
        Reference: <a href="http://www.euclideanspace.com/maths/geometry/rotations/conversions/matrixToAngle/">http://www.euclideanspace.com</a>

        Arguments
        - m: the Matrix3fc to set this AngleAxis4d from

        Returns
        - this
        """
        ...


    def set(self, m: "Matrix3dc") -> "AxisAngle4d":
        """
        Set this AxisAngle4d to be equivalent to the rotation 
        of the given Matrix3dc.
        
        Reference: <a href="http://www.euclideanspace.com/maths/geometry/rotations/conversions/matrixToAngle/">http://www.euclideanspace.com</a>

        Arguments
        - m: the Matrix3dc to set this AngleAxis4d from

        Returns
        - this
        """
        ...


    def set(self, m: "Matrix4fc") -> "AxisAngle4d":
        """
        Set this AxisAngle4d to be equivalent to the rotational component 
        of the given Matrix4fc.
        
        Reference: <a href="http://www.euclideanspace.com/maths/geometry/rotations/conversions/matrixToAngle/">http://www.euclideanspace.com</a>

        Arguments
        - m: the Matrix4fc to set this AngleAxis4d from

        Returns
        - this
        """
        ...


    def set(self, m: "Matrix4x3fc") -> "AxisAngle4d":
        """
        Set this AxisAngle4d to be equivalent to the rotational component 
        of the given Matrix4x3fc.
        
        Reference: <a href="http://www.euclideanspace.com/maths/geometry/rotations/conversions/matrixToAngle/">http://www.euclideanspace.com</a>

        Arguments
        - m: the Matrix4x3fc to set this AngleAxis4d from

        Returns
        - this
        """
        ...


    def set(self, m: "Matrix4dc") -> "AxisAngle4d":
        """
        Set this AxisAngle4d to be equivalent to the rotational component 
        of the given Matrix4dc.
        
        Reference: <a href="http://www.euclideanspace.com/maths/geometry/rotations/conversions/matrixToAngle/">http://www.euclideanspace.com</a>

        Arguments
        - m: the Matrix4dc to set this AngleAxis4d from

        Returns
        - this
        """
        ...


    def get(self, q: "Quaternionf") -> "Quaternionf":
        """
        Set the given Quaternionf to be equivalent to this AxisAngle4d rotation.

        Arguments
        - q: the quaternion to set

        Returns
        - q

        See
        - Quaternionf.set(AxisAngle4d)
        """
        ...


    def get(self, q: "Quaterniond") -> "Quaterniond":
        """
        Set the given Quaterniond to be equivalent to this AxisAngle4d rotation.

        Arguments
        - q: the quaternion to set

        Returns
        - q

        See
        - Quaterniond.set(AxisAngle4d)
        """
        ...


    def get(self, m: "Matrix4f") -> "Matrix4f":
        """
        Set the given Matrix4f to a rotation transformation equivalent to this AxisAngle4d.

        Arguments
        - m: the matrix to set

        Returns
        - m

        See
        - Matrix4f.set(AxisAngle4d)
        """
        ...


    def get(self, m: "Matrix3f") -> "Matrix3f":
        """
        Set the given Matrix3f to a rotation transformation equivalent to this AxisAngle4d.

        Arguments
        - m: the matrix to set

        Returns
        - m

        See
        - Matrix3f.set(AxisAngle4d)
        """
        ...


    def get(self, m: "Matrix4d") -> "Matrix4d":
        """
        Set the given Matrix4d to a rotation transformation equivalent to this AxisAngle4d.

        Arguments
        - m: the matrix to set

        Returns
        - m

        See
        - Matrix4f.set(AxisAngle4d)
        """
        ...


    def get(self, m: "Matrix3d") -> "Matrix3d":
        """
        Set the given Matrix3d to a rotation transformation equivalent to this AxisAngle4d.

        Arguments
        - m: the matrix to set

        Returns
        - m

        See
        - Matrix3f.set(AxisAngle4d)
        """
        ...


    def get(self, dest: "AxisAngle4d") -> "AxisAngle4d":
        """
        Set the given AxisAngle4d to this AxisAngle4d.

        Arguments
        - dest: will hold the result

        Returns
        - dest
        """
        ...


    def get(self, dest: "AxisAngle4f") -> "AxisAngle4f":
        """
        Set the given AxisAngle4f to this AxisAngle4d.

        Arguments
        - dest: will hold the result

        Returns
        - dest
        """
        ...


    def writeExternal(self, out: "ObjectOutput") -> None:
        ...


    def readExternal(self, in: "ObjectInput") -> None:
        ...


    def normalize(self) -> "AxisAngle4d":
        """
        Normalize the axis vector.

        Returns
        - this
        """
        ...


    def rotate(self, ang: float) -> "AxisAngle4d":
        """
        Increase the rotation angle by the given amount.
        
        This method also takes care of wrapping around.

        Arguments
        - ang: the angle increase

        Returns
        - this
        """
        ...


    def transform(self, v: "Vector3d") -> "Vector3d":
        """
        Transform the given vector by the rotation transformation described by this AxisAngle4d.

        Arguments
        - v: the vector to transform

        Returns
        - v
        """
        ...


    def transform(self, v: "Vector3dc", dest: "Vector3d") -> "Vector3d":
        """
        Transform the given vector by the rotation transformation described by this AxisAngle4d
        and store the result in `dest`.

        Arguments
        - v: the vector to transform
        - dest: will hold the result

        Returns
        - dest
        """
        ...


    def transform(self, v: "Vector3f") -> "Vector3f":
        """
        Transform the given vector by the rotation transformation described by this AxisAngle4d.

        Arguments
        - v: the vector to transform

        Returns
        - v
        """
        ...


    def transform(self, v: "Vector3fc", dest: "Vector3f") -> "Vector3f":
        """
        Transform the given vector by the rotation transformation described by this AxisAngle4d
        and store the result in `dest`.

        Arguments
        - v: the vector to transform
        - dest: will hold the result

        Returns
        - dest
        """
        ...


    def transform(self, v: "Vector4d") -> "Vector4d":
        """
        Transform the given vector by the rotation transformation described by this AxisAngle4d.

        Arguments
        - v: the vector to transform

        Returns
        - v
        """
        ...


    def transform(self, v: "Vector4dc", dest: "Vector4d") -> "Vector4d":
        """
        Transform the given vector by the rotation transformation described by this AxisAngle4d
        and store the result in `dest`.

        Arguments
        - v: the vector to transform
        - dest: will hold the result

        Returns
        - dest
        """
        ...


    def toString(self) -> str:
        """
        Return a string representation of this AxisAngle4d.
        
        This method creates a new DecimalFormat on every invocation with the format string "` 0.000E0;-`".

        Returns
        - the string representation
        """
        ...


    def toString(self, formatter: "NumberFormat") -> str:
        """
        Return a string representation of this AxisAngle4d by formatting the components with the given NumberFormat.

        Arguments
        - formatter: the NumberFormat used to format the vector components with

        Returns
        - the string representation
        """
        ...


    def hashCode(self) -> int:
        ...


    def equals(self, obj: "Object") -> bool:
        ...


    def clone(self) -> "Object":
        ...



"""
Python module generated from Java source file org.bukkit.inventory.meta.MusicInstrumentMeta

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit import MusicInstrument
from org.bukkit.inventory.meta import *
from typing import Any, Callable, Iterable, Tuple


class MusicInstrumentMeta(ItemMeta):

    def setInstrument(self, instrument: "MusicInstrument") -> None:
        """
        Sets the goat horn's instrument.

        Arguments
        - instrument: the instrument to set
        """
        ...


    def getInstrument(self) -> "MusicInstrument":
        """
        Gets the instrument of the goat horn.

        Returns
        - The instrument of the goat horn
        """
        ...


    def clone(self) -> "MusicInstrumentMeta":
        ...



"""
Python module generated from Java source file org.bukkit.event.raid.RaidEvent

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit import Raid
from org.bukkit import World
from org.bukkit.event.raid import *
from org.bukkit.event.world import WorldEvent
from typing import Any, Callable, Iterable, Tuple


class RaidEvent(WorldEvent):
    """
    Represents events related to raids.
    """

    def getRaid(self) -> "Raid":
        """
        Returns the raid involved with this event.

        Returns
        - Raid
        """
        ...



"""
Python module generated from Java source file org.bukkit.BanList

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from enum import Enum
from java.time import Duration
from java.time import Instant
from java.util import Date
from org.bukkit import *
from typing import Any, Callable, Iterable, Tuple


class BanList:
    """
    A ban list, containing bans of some Type.
    
    Type `<T>`: The ban target
    """

    def getBanEntry(self, target: str) -> "BanEntry"["T"]:
        """
        Gets a BanEntry by target.

        Arguments
        - target: entry parameter to search for

        Returns
        - the corresponding entry, or null if none found

        Deprecated
        - see .getBanEntry(Object)
        """
        ...


    def getBanEntry(self, target: "T") -> "BanEntry"["T"]:
        """
        Gets a BanEntry by target.

        Arguments
        - target: entry parameter to search for

        Returns
        - the corresponding entry, or null if none found
        """
        ...


    def addBan(self, target: str, reason: str, expires: "Date", source: str) -> "BanEntry"["T"]:
        """
        Adds a ban to this list. If a previous ban exists, this will
        update the previous entry.

        Arguments
        - target: the target of the ban
        - reason: reason for the ban, null indicates implementation default
        - expires: date for the ban's expiration (unban), or null to imply
            forever
        - source: source of the ban, null indicates implementation default

        Returns
        - the entry for the newly created ban, or the entry for the
            (updated) previous ban

        Deprecated
        - see .addBan(Object, String, Date, String)
        """
        ...


    def addBan(self, target: "T", reason: str, expires: "Date", source: str) -> "BanEntry"["T"]:
        """
        Adds a ban to this list. If a previous ban exists, this will
        update the previous entry.

        Arguments
        - target: the target of the ban
        - reason: reason for the ban, null indicates implementation default
        - expires: date for the ban's expiration (unban), or null to imply
            forever
        - source: source of the ban, null indicates implementation default

        Returns
        - the entry for the newly created ban, or the entry for the
            (updated) previous ban
        """
        ...


    def addBan(self, target: "T", reason: str, expires: "Instant", source: str) -> "BanEntry"["T"]:
        """
        Adds a ban to this list. If a previous ban exists, this will
        update the previous entry.

        Arguments
        - target: the target of the ban
        - reason: reason for the ban, null indicates implementation default
        - expires: instant for the ban's expiration (unban), or null to imply
            forever
        - source: source of the ban, null indicates implementation default

        Returns
        - the entry for the newly created ban, or the entry for the
            (updated) previous ban
        """
        ...


    def addBan(self, target: "T", reason: str, duration: "Duration", source: str) -> "BanEntry"["T"]:
        """
        Adds a ban to this list. If a previous ban exists, this will
        update the previous entry.

        Arguments
        - target: the target of the ban
        - reason: reason for the ban, null indicates implementation default
        - duration: the duration of the ban, or null to imply
            forever
        - source: source of the ban, null indicates implementation default

        Returns
        - the entry for the newly created ban, or the entry for the
            (updated) previous ban
        """
        ...


    def getBanEntries(self) -> set["BanEntry"]:
        """
        Gets a set containing every BanEntry in this list.

        Returns
        - an immutable set containing every entry tracked by this list

        Deprecated
        - This return a generic class, prefer use .getEntries()
        """
        ...


    def getEntries(self) -> set["BanEntry"["T"]]:
        """
        Gets a set containing every BanEntry in this list.

        Returns
        - an immutable set containing every entry tracked by this list
        """
        ...


    def isBanned(self, target: "T") -> bool:
        """
        Gets if a BanEntry exists for the target, indicating an active
        ban status.

        Arguments
        - target: the target to find

        Returns
        - True if a BanEntry exists for the target, indicating an
            active ban status, False otherwise
        """
        ...


    def isBanned(self, target: str) -> bool:
        """
        Gets if a BanEntry exists for the target, indicating an active
        ban status.

        Arguments
        - target: the target to find

        Returns
        - True if a BanEntry exists for the target, indicating an
            active ban status, False otherwise

        Deprecated
        - see .isBanned(Object)
        """
        ...


    def pardon(self, target: "T") -> None:
        """
        Removes the specified target from this list, therefore indicating a
        "not banned" status.

        Arguments
        - target: the target to remove from this list
        """
        ...


    def pardon(self, target: str) -> None:
        """
        Removes the specified target from this list, therefore indicating a
        "not banned" status.

        Arguments
        - target: the target to remove from this list

        Deprecated
        - see .pardon(Object)
        """
        ...


    class Type(Enum):
        """
        Represents a ban-type that a BanList may track.
        """

        NAME = 0
        """
        Banned player names

        Deprecated
        - deprecated in favor of .PROFILE
        """
        IP = 1
        """
        Banned IP addresses
        """
        PROFILE = 2
        """
        Banned player profiles
        """



"""
Python module generated from Java source file org.bukkit.command.defaults.TimingsCommand

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.base import Preconditions
from com.google.common.collect import ImmutableList
from java.io import ByteArrayOutputStream
from java.io import File
from java.io import IOException
from java.io import OutputStream
from java.io import PrintStream
from java.net import HttpURLConnection
from java.net import URL
from org.bukkit import Bukkit
from org.bukkit import ChatColor
from org.bukkit.command import CommandSender
from org.bukkit.command import RemoteConsoleCommandSender
from org.bukkit.command.defaults import *
from org.bukkit.event import Event
from org.bukkit.event import HandlerList
from org.bukkit.plugin import Plugin
from org.bukkit.plugin import RegisteredListener
from org.bukkit.plugin import SimplePluginManager
from org.bukkit.plugin import TimedRegisteredListener
from org.bukkit.util import StringUtil
from org.spigotmc import CustomTimingsHandler
from typing import Any, Callable, Iterable, Tuple


class TimingsCommand(BukkitCommand):

    timingStart = 0


    def __init__(self, name: str):
        ...


    def executeSpigotTimings(self, sender: "CommandSender", args: list[str]) -> None:
        ...


    def execute(self, sender: "CommandSender", currentAlias: str, args: list[str]) -> bool:
        ...


    def tabComplete(self, sender: "CommandSender", alias: str, args: list[str]) -> list[str]:
        ...



"""
Python module generated from Java source file com.google.common.io.LittleEndianDataOutputStream

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtIncompatible
from com.google.common.annotations import J2ktIncompatible
from com.google.common.base import Preconditions
from com.google.common.io import *
from com.google.common.primitives import Longs
from java.io import DataOutput
from java.io import DataOutputStream
from java.io import FilterOutputStream
from java.io import IOException
from java.io import OutputStream
from typing import Any, Callable, Iterable, Tuple


class LittleEndianDataOutputStream(FilterOutputStream, DataOutput):
    """
    An implementation of DataOutput that uses little-endian byte ordering for writing `char`, `short`, `int`, `float`, `double`, and `long` values.
    
    **Note:** This class intentionally violates the specification of its supertype `DataOutput`, which explicitly requires big-endian byte order.

    Author(s)
    - Keith Bottner

    Since
    - 8.0
    """

    def __init__(self, out: "OutputStream"):
        """
        Creates a `LittleEndianDataOutputStream` that wraps the given stream.

        Arguments
        - out: the stream to delegate to
        """
        ...


    def write(self, b: list[int], off: int, len: int) -> None:
        ...


    def writeBoolean(self, v: bool) -> None:
        ...


    def writeByte(self, v: int) -> None:
        ...


    def writeBytes(self, s: str) -> None:
        """
        Deprecated
        - The semantics of `writeBytes(String s)` are considered dangerous. Please use
            .writeUTF(String s), .writeChars(String s) or another write method instead.
        """
        ...


    def writeChar(self, v: int) -> None:
        """
        Writes a char as specified by DataOutputStream.writeChar(int), except using
        little-endian byte order.

        Raises
        - IOException: if an I/O error occurs
        """
        ...


    def writeChars(self, s: str) -> None:
        """
        Writes a `String` as specified by DataOutputStream.writeChars(String), except
        each character is written using little-endian byte order.

        Raises
        - IOException: if an I/O error occurs
        """
        ...


    def writeDouble(self, v: float) -> None:
        """
        Writes a `double` as specified by DataOutputStream.writeDouble(double), except
        using little-endian byte order.

        Raises
        - IOException: if an I/O error occurs
        """
        ...


    def writeFloat(self, v: float) -> None:
        """
        Writes a `float` as specified by DataOutputStream.writeFloat(float), except using
        little-endian byte order.

        Raises
        - IOException: if an I/O error occurs
        """
        ...


    def writeInt(self, v: int) -> None:
        """
        Writes an `int` as specified by DataOutputStream.writeInt(int), except using
        little-endian byte order.

        Raises
        - IOException: if an I/O error occurs
        """
        ...


    def writeLong(self, v: int) -> None:
        """
        Writes a `long` as specified by DataOutputStream.writeLong(long), except using
        little-endian byte order.

        Raises
        - IOException: if an I/O error occurs
        """
        ...


    def writeShort(self, v: int) -> None:
        """
        Writes a `short` as specified by DataOutputStream.writeShort(int), except using
        little-endian byte order.

        Raises
        - IOException: if an I/O error occurs
        """
        ...


    def writeUTF(self, str: str) -> None:
        ...


    def close(self) -> None:
        ...



"""
Python module generated from Java source file java.util.concurrent.LinkedBlockingQueue

Java source file obtained from artifact jdk version jdk

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.util import AbstractQueue
from java.util import Iterator
from java.util import NoSuchElementException
from java.util import Objects
from java.util import Spliterator
from java.util.concurrent import *
from java.util.concurrent.atomic import AtomicInteger
from java.util.concurrent.locks import Condition
from java.util.concurrent.locks import ReentrantLock
from java.util.function import Consumer
from java.util.function import Predicate
from typing import Any, Callable, Iterable, Tuple


class LinkedBlockingQueue(AbstractQueue, BlockingQueue, Serializable):
    """
    An optionally-bounded BlockingQueue blocking queue based on
    linked nodes.
    This queue orders elements FIFO (first-in-first-out).
    The *head* of the queue is that element that has been on the
    queue the longest time.
    The *tail* of the queue is that element that has been on the
    queue the shortest time. New elements
    are inserted at the tail of the queue, and the queue retrieval
    operations obtain elements at the head of the queue.
    Linked queues typically have higher throughput than array-based queues but
    less predictable performance in most concurrent applications.
    
    The optional capacity bound constructor argument serves as a
    way to prevent excessive queue expansion. The capacity, if unspecified,
    is equal to Integer.MAX_VALUE.  Linked nodes are
    dynamically created upon each insertion unless this would bring the
    queue above capacity.
    
    This class and its iterator implement all of the *optional*
    methods of the Collection and Iterator interfaces.
    
    This class is a member of the
    <a href="/java.base/java/util/package-summary.html#CollectionsFramework">
    Java Collections Framework</a>.
    
    Type `<E>`: the type of elements held in this queue

    Author(s)
    - Doug Lea

    Since
    - 1.5
    """

    def __init__(self):
        """
        Creates a `LinkedBlockingQueue` with a capacity of
        Integer.MAX_VALUE.
        """
        ...


    def __init__(self, capacity: int):
        """
        Creates a `LinkedBlockingQueue` with the given (fixed) capacity.

        Arguments
        - capacity: the capacity of this queue

        Raises
        - IllegalArgumentException: if `capacity` is not greater
                than zero
        """
        ...


    def __init__(self, c: Iterable["E"]):
        """
        Creates a `LinkedBlockingQueue` with a capacity of
        Integer.MAX_VALUE, initially containing the elements of the
        given collection,
        added in traversal order of the collection's iterator.

        Arguments
        - c: the collection of elements to initially contain

        Raises
        - NullPointerException: if the specified collection or any
                of its elements are null
        """
        ...


    def size(self) -> int:
        """
        Returns the number of elements in this queue.

        Returns
        - the number of elements in this queue
        """
        ...


    def remainingCapacity(self) -> int:
        """
        Returns the number of additional elements that this queue can ideally
        (in the absence of memory or resource constraints) accept without
        blocking. This is always equal to the initial capacity of this queue
        less the current `size` of this queue.
        
        Note that you *cannot* always tell if an attempt to insert
        an element will succeed by inspecting `remainingCapacity`
        because it may be the case that another thread is about to
        insert or remove an element.
        """
        ...


    def put(self, e: "E") -> None:
        """
        Inserts the specified element at the tail of this queue, waiting if
        necessary for space to become available.

        Raises
        - InterruptedException: 
        - NullPointerException: 
        """
        ...


    def offer(self, e: "E", timeout: int, unit: "TimeUnit") -> bool:
        """
        Inserts the specified element at the tail of this queue, waiting if
        necessary up to the specified wait time for space to become available.

        Returns
        - `True` if successful, or `False` if
                the specified waiting time elapses before space is available

        Raises
        - InterruptedException: 
        - NullPointerException: 
        """
        ...


    def offer(self, e: "E") -> bool:
        """
        Inserts the specified element at the tail of this queue if it is
        possible to do so immediately without exceeding the queue's capacity,
        returning `True` upon success and `False` if this queue
        is full.
        When using a capacity-restricted queue, this method is generally
        preferable to method BlockingQueue.add add, which can fail to
        insert an element only by throwing an exception.

        Raises
        - NullPointerException: if the specified element is null
        """
        ...


    def take(self) -> "E":
        ...


    def poll(self, timeout: int, unit: "TimeUnit") -> "E":
        ...


    def poll(self) -> "E":
        ...


    def peek(self) -> "E":
        ...


    def remove(self, o: "Object") -> bool:
        """
        Removes a single instance of the specified element from this queue,
        if it is present.  More formally, removes an element `e` such
        that `o.equals(e)`, if this queue contains one or more such
        elements.
        Returns `True` if this queue contained the specified element
        (or equivalently, if this queue changed as a result of the call).

        Arguments
        - o: element to be removed from this queue, if present

        Returns
        - `True` if this queue changed as a result of the call
        """
        ...


    def contains(self, o: "Object") -> bool:
        """
        Returns `True` if this queue contains the specified element.
        More formally, returns `True` if and only if this queue contains
        at least one element `e` such that `o.equals(e)`.

        Arguments
        - o: object to be checked for containment in this queue

        Returns
        - `True` if this queue contains the specified element
        """
        ...


    def toArray(self) -> list["Object"]:
        """
        Returns an array containing all of the elements in this queue, in
        proper sequence.
        
        The returned array will be "safe" in that no references to it are
        maintained by this queue.  (In other words, this method must allocate
        a new array).  The caller is thus free to modify the returned array.
        
        This method acts as bridge between array-based and collection-based
        APIs.

        Returns
        - an array containing all of the elements in this queue
        """
        ...


    def toArray(self, a: list["T"]) -> list["T"]:
        """
        Returns an array containing all of the elements in this queue, in
        proper sequence; the runtime type of the returned array is that of
        the specified array.  If the queue fits in the specified array, it
        is returned therein.  Otherwise, a new array is allocated with the
        runtime type of the specified array and the size of this queue.
        
        If this queue fits in the specified array with room to spare
        (i.e., the array has more elements than this queue), the element in
        the array immediately following the end of the queue is set to
        `null`.
        
        Like the .toArray() method, this method acts as bridge between
        array-based and collection-based APIs.  Further, this method allows
        precise control over the runtime type of the output array, and may,
        under certain circumstances, be used to save allocation costs.
        
        Suppose `x` is a queue known to contain only strings.
        The following code can be used to dump the queue into a newly
        allocated array of `String`:
        
        ``` `String[] y = x.toArray(new String[0]);````
        
        Note that `toArray(new Object[0])` is identical in function to
        `toArray()`.

        Arguments
        - a: the array into which the elements of the queue are to
                 be stored, if it is big enough; otherwise, a new array of the
                 same runtime type is allocated for this purpose

        Returns
        - an array containing all of the elements in this queue

        Raises
        - ArrayStoreException: if the runtime type of the specified array
                is not a supertype of the runtime type of every element in
                this queue
        - NullPointerException: if the specified array is null
        """
        ...


    def toString(self) -> str:
        ...


    def clear(self) -> None:
        """
        Atomically removes all of the elements from this queue.
        The queue will be empty after this call returns.
        """
        ...


    def drainTo(self, c: Iterable["E"]) -> int:
        """
        Raises
        - UnsupportedOperationException: 
        - ClassCastException: 
        - NullPointerException: 
        - IllegalArgumentException: 
        """
        ...


    def drainTo(self, c: Iterable["E"], maxElements: int) -> int:
        """
        Raises
        - UnsupportedOperationException: 
        - ClassCastException: 
        - NullPointerException: 
        - IllegalArgumentException: 
        """
        ...


    def iterator(self) -> Iterator["E"]:
        """
        Returns an iterator over the elements in this queue in proper sequence.
        The elements will be returned in order from first (head) to last (tail).
        
        The returned iterator is
        <a href="package-summary.html#Weakly">*weakly consistent*</a>.

        Returns
        - an iterator over the elements in this queue in proper sequence
        """
        ...


    def spliterator(self) -> "Spliterator"["E"]:
        """
        Returns a Spliterator over the elements in this queue.
        
        The returned spliterator is
        <a href="package-summary.html#Weakly">*weakly consistent*</a>.
        
        The `Spliterator` reports Spliterator.CONCURRENT,
        Spliterator.ORDERED, and Spliterator.NONNULL.

        Returns
        - a `Spliterator` over the elements in this queue

        Since
        - 1.8

        Unknown Tags
        - The `Spliterator` implements `trySplit` to permit limited
        parallelism.
        """
        ...


    def forEach(self, action: "Consumer"["E"]) -> None:
        """
        Raises
        - NullPointerException: 
        """
        ...


    def removeIf(self, filter: "Predicate"["E"]) -> bool:
        """
        Raises
        - NullPointerException: 
        """
        ...


    def removeAll(self, c: Iterable[Any]) -> bool:
        """
        Raises
        - NullPointerException: 
        """
        ...


    def retainAll(self, c: Iterable[Any]) -> bool:
        """
        Raises
        - NullPointerException: 
        """
        ...



"""
Python module generated from Java source file org.bukkit.entity.Vindicator

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.entity import *
from typing import Any, Callable, Iterable, Tuple


class Vindicator(Illager):
    """
    Represents a Vindicator.
    """

    def isJohnny(self) -> bool:
        """
        Returns whether a vindicator is in "Johnny" mode.
        
        When this mode is active, vindicators will be hostile to all mobs.

        Returns
        - True if johnny
        """
        ...


    def setJohnny(self, johnny: bool) -> None:
        """
        Sets the Johnny state of a vindicator.

        Arguments
        - johnny: new johnny state
        """
        ...



"""
Python module generated from Java source file org.bukkit.block.BlockState

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit import Chunk
from org.bukkit import Location
from org.bukkit import Material
from org.bukkit import World
from org.bukkit.block import *
from org.bukkit.block.data import BlockData
from org.bukkit.material import MaterialData
from org.bukkit.metadata import Metadatable
from typing import Any, Callable, Iterable, Tuple


class BlockState(Metadatable):
    """
    Represents a captured state of a block, which will not change
    automatically.
    
    Unlike Block, which only one object can exist per coordinate, BlockState
    can exist multiple times for any given Block. Note that another plugin may
    change the state of the block and you will not know, or they may change the
    block to another type entirely, causing your BlockState to become invalid.
    """

    def getBlock(self) -> "Block":
        """
        Gets the block represented by this block state.

        Returns
        - the block represented by this block state

        Raises
        - IllegalStateException: if this block state is not placed
        """
        ...


    def getData(self) -> "MaterialData":
        """
        Gets the metadata for this block state.

        Returns
        - block specific metadata
        """
        ...


    def getBlockData(self) -> "BlockData":
        """
        Gets the data for this block state.

        Returns
        - block specific data
        """
        ...


    def copy(self) -> "BlockState":
        """
        Returns a copy of this BlockState as an unplaced BlockState.

        Returns
        - a copy of the block state
        """
        ...


    def copy(self, location: "Location") -> "BlockState":
        """
        Copies the state to another block as an unplaced BlockState.

        Arguments
        - location: the location to copy the block state to

        Returns
        - the new block state
        """
        ...


    def getType(self) -> "Material":
        """
        Gets the type of this block state.

        Returns
        - block type
        """
        ...


    def getLightLevel(self) -> int:
        """
        Gets the current light level of the block represented by this block state.

        Returns
        - the light level between 0-15

        Raises
        - IllegalStateException: if this block state is not placed
        """
        ...


    def getWorld(self) -> "World":
        """
        Gets the world which contains the block represented by this block state.

        Returns
        - the world containing the block represented by this block state

        Raises
        - IllegalStateException: if this block state is not placed
        """
        ...


    def getX(self) -> int:
        """
        Gets the x-coordinate of this block state.

        Returns
        - x-coordinate
        """
        ...


    def getY(self) -> int:
        """
        Gets the y-coordinate of this block state.

        Returns
        - y-coordinate
        """
        ...


    def getZ(self) -> int:
        """
        Gets the z-coordinate of this block state.

        Returns
        - z-coordinate
        """
        ...


    def getLocation(self) -> "Location":
        """
        Gets the location of this block state.
        
        If this block state is not placed the location's world will be null!

        Returns
        - the location
        """
        ...


    def getLocation(self, loc: "Location") -> "Location":
        """
        Stores the location of this block state in the provided Location object.
        
        If the provided Location is null this method does nothing and returns
        null.
        
        If this block state is not placed the location's world will be null!

        Arguments
        - loc: the location to copy into

        Returns
        - The Location object provided or null
        """
        ...


    def getChunk(self) -> "Chunk":
        """
        Gets the chunk which contains the block represented by this block state.

        Returns
        - the containing Chunk

        Raises
        - IllegalStateException: if this block state is not placed
        """
        ...


    def setData(self, data: "MaterialData") -> None:
        """
        Sets the metadata for this block state.

        Arguments
        - data: New block specific metadata
        """
        ...


    def setBlockData(self, data: "BlockData") -> None:
        """
        Sets the data for this block state.

        Arguments
        - data: New block specific data
        """
        ...


    def setType(self, type: "Material") -> None:
        """
        Sets the type of this block state.

        Arguments
        - type: Material to change this block state to
        """
        ...


    def update(self) -> bool:
        """
        Attempts to update the block represented by this state, setting it to
        the new values as defined by this state.
        
        This has the same effect as calling update(False). That is to say,
        this will not modify the state of a block if it is no longer the same
        type as it was when this state was taken. It will return False in this
        eventuality.

        Returns
        - True if the update was successful, otherwise False

        See
        - .update(boolean)
        """
        ...


    def update(self, force: bool) -> bool:
        """
        Attempts to update the block represented by this state, setting it to
        the new values as defined by this state.
        
        This has the same effect as calling update(force, True). That is to
        say, this will trigger a physics update to surrounding blocks.

        Arguments
        - force: True to forcefully set the state

        Returns
        - True if the update was successful, otherwise False
        """
        ...


    def update(self, force: bool, applyPhysics: bool) -> bool:
        """
        Attempts to update the block represented by this state, setting it to
        the new values as defined by this state.
        
        If this state is not placed, this will have no effect and return True.
        
        Unless force is True, this will not modify the state of a block if it
        is no longer the same type as it was when this state was taken. It will
        return False in this eventuality.
        
        If force is True, it will set the type of the block to match the new
        state, set the state data and then return True.
        
        If applyPhysics is True, it will trigger a physics update on
        surrounding blocks which could cause them to update or disappear.

        Arguments
        - force: True to forcefully set the state
        - applyPhysics: False to cancel updating physics on surrounding
            blocks

        Returns
        - True if the update was successful, otherwise False
        """
        ...


    def getRawData(self) -> int:
        """
        Returns
        - The data as a raw byte.

        Deprecated
        - Magic value
        """
        ...


    def setRawData(self, data: int) -> None:
        """
        Arguments
        - data: The new data value for the block.

        Deprecated
        - Magic value
        """
        ...


    def isPlaced(self) -> bool:
        """
        Returns whether this state is placed in the world.
        
        Some methods will not work if the block state isn't
        placed in the world.

        Returns
        - whether the state is placed in the world
                or 'virtual' (e.g. on an itemstack)
        """
        ...



"""
Python module generated from Java source file org.bukkit.event.entity.PiglinBarterEvent

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.entity import Piglin
from org.bukkit.event import Cancellable
from org.bukkit.event import HandlerList
from org.bukkit.event.entity import *
from org.bukkit.inventory import ItemStack
from typing import Any, Callable, Iterable, Tuple


class PiglinBarterEvent(EntityEvent, Cancellable):
    """
    Stores all data related to the bartering interaction with a piglin.
    
    This event can be triggered by a piglin picking up an item that's on its
    bartering list.
    """

    def __init__(self, what: "Piglin", input: "ItemStack", outcome: list["ItemStack"]):
        ...


    def getEntity(self) -> "Piglin":
        ...


    def getInput(self) -> "ItemStack":
        """
        Gets the input of the barter.

        Returns
        - The item that was used to barter with
        """
        ...


    def getOutcome(self) -> list["ItemStack"]:
        """
        Returns a mutable list representing the outcome of the barter.

        Returns
        - A mutable list of the item the player will receive
        """
        ...


    def isCancelled(self) -> bool:
        ...


    def setCancelled(self, cancel: bool) -> None:
        ...


    def getHandlers(self) -> "HandlerList":
        ...


    @staticmethod
    def getHandlerList() -> "HandlerList":
        ...



"""
Python module generated from Java source file org.bukkit.block.spawner.SpawnerEntry

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.base import Preconditions
from org.bukkit.block.spawner import *
from org.bukkit.entity import EntitySnapshot
from org.bukkit.inventory import EquipmentSlot
from org.bukkit.loot import LootTable
from typing import Any, Callable, Iterable, Tuple


class SpawnerEntry:
    """
    Represents a weighted spawn potential that can be added to a monster spawner.
    """

    def __init__(self, snapshot: "EntitySnapshot", spawnWeight: int, spawnRule: "SpawnRule"):
        ...


    def __init__(self, snapshot: "EntitySnapshot", spawnWeight: int, spawnRule: "SpawnRule", equipment: "Equipment"):
        ...


    def getSnapshot(self) -> "EntitySnapshot":
        """
        Gets the EntitySnapshot for this SpawnerEntry.

        Returns
        - the snapshot
        """
        ...


    def setSnapshot(self, snapshot: "EntitySnapshot") -> None:
        """
        Sets the EntitySnapshot for this SpawnerEntry.

        Arguments
        - snapshot: the snapshot
        """
        ...


    def getSpawnWeight(self) -> int:
        """
        Gets the weight for this SpawnerEntry, when added to a spawner entries
        with higher weight will spawn more often.

        Returns
        - the weight
        """
        ...


    def setSpawnWeight(self, spawnWeight: int) -> None:
        """
        Sets the weight for this SpawnerEntry, when added to a spawner entries
        with higher weight will spawn more often.

        Arguments
        - spawnWeight: the new spawn weight
        """
        ...


    def getSpawnRule(self) -> "SpawnRule":
        """
        Gets a copy of the SpawnRule for this SpawnerEntry, or null if
        none has been set.

        Returns
        - a copy of the spawn rule or null
        """
        ...


    def setSpawnRule(self, spawnRule: "SpawnRule") -> None:
        """
        Sets the SpawnRule for this SpawnerEntry, null may be used to
        clear the current spawn rule.

        Arguments
        - spawnRule: the new spawn rule to use or null
        """
        ...


    def getEquipment(self) -> "Equipment":
        """
        Gets the equipment which will be applied to the spawned entity.

        Returns
        - the equipment, or null
        """
        ...


    def setEquipment(self, equipment: "Equipment") -> None:
        """
        Sets the equipment which will be applied to the spawned entity.

        Arguments
        - equipment: new equipment, or null
        """
        ...


    class Equipment:
        """
        Represents the equipment loot table applied to a spawned entity.
        """

        def __init__(self, equipmentLootTable: "LootTable", dropChances: dict["EquipmentSlot", "Float"]):
            ...


        def setEquipmentLootTable(self, table: "LootTable") -> None:
            """
            Set the loot table for the entity.
            
            To remove a loot table use null.

            Arguments
            - table: this org.bukkit.entity.Mob will have.
            """
            ...


        def getEquipmentLootTable(self) -> "LootTable":
            """
            Gets the loot table for the entity.
            
            
            If an entity does not have a loot table, this will return null, NOT
            an empty loot table.

            Returns
            - the loot table for this entity.
            """
            ...


        def getDropChances(self) -> dict["EquipmentSlot", "Float"]:
            """
            Gets a mutable map of the drop chances for each slot of the entity.
            If non-null, the entity's drop chances will be overridden with the
            given value.

            Returns
            - mutable map of drop chances
            """
            ...



"""
Python module generated from Java source file org.bukkit.inventory.LlamaInventory

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.entity import Llama
from org.bukkit.inventory import *
from typing import Any, Callable, Iterable, Tuple


class LlamaInventory(AbstractHorseInventory):
    """
    An interface to the inventory of a Llama.
    """

    def getDecor(self) -> "ItemStack":
        """
        Gets the item in the llama's decor slot.

        Returns
        - the decor item
        """
        ...


    def setDecor(self, stack: "ItemStack") -> None:
        """
        Sets the item in the llama's decor slot.

        Arguments
        - stack: the new item
        """
        ...
